pub struct RaySubmitTask {
pub job_name: String,
pub entrypoint: String,
pub head_address: String,
pub dashboard_port: u16,
pub working_dir: Option<String>,
}Expand description
Submit a ray job via the Ray Jobs API.
Fields
job_name: Stringentrypoint: Stringhead_address: Stringdashboard_port: u16working_dir: Option<String>Trait Implementations
Sourceimpl DagTask for RaySubmitTask
impl DagTask for RaySubmitTask
Sourcefn execute(&self, ctx: &DagContext) -> TaskOutcome
fn execute(&self, ctx: &DagContext) -> TaskOutcome
Execute this task.
Sourcefn resource_tag(&self) -> Option<&str>
fn resource_tag(&self) -> Option<&str>
Optional resource tag for worker pool slot management.
Tasks with a resource tag require a matching slot in the pool.