pub struct RayWaitTask {
pub job_name: String,
pub head_address: String,
pub dashboard_port: u16,
pub poll_interval: Duration,
pub timeout: Option<Duration>,
}Expand description
Wait for a ray job to complete by polling the Jobs API.
Fields
job_name: Stringhead_address: Stringdashboard_port: u16poll_interval: Durationtimeout: Option<Duration>Trait Implementations
Sourceimpl DagTask for RayWaitTask
impl DagTask for RayWaitTask
Sourcefn execute(&self, ctx: &DagContext) -> TaskOutcome
fn execute(&self, ctx: &DagContext) -> TaskOutcome
Execute this task.
Sourcefn resource_tag(&self) -> Option<&str>
fn resource_tag(&self) -> Option<&str>
Optional resource tag for worker pool slot management.
Tasks with a resource tag require a matching slot in the pool.